Index — Parally documentation

# Index

B | C | M | O | P | R | S

## B

bind_parameters() (in module parally.Server)

## C

close() (in module parally.Client)

## M

module parally.Client parally.Server

## O

on_completed() (in module parally.Server) | on_error() (in module parally.Server)

## P

parally.Client module | parally.Server module

## R

run_function() (in module parally.Client)

## S

start() (in module parally.Client) (in module parally.Server) | stop() (in module parally.Server)